==> jc-1.4.0.tar.gz: java/nio/channels/spi/AbstractInterruptibleChannel.h <==
// public abstract class java.nio.channels.spi.AbstractInterruptibleChannel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_spi_AbstractInterruptibleChannel_H_
#define _JC_java_nio_channels_spi_AbstractInterruptibleChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$object;

typedef const struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods;
typedef const struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable;
typedef const struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);

// Virtual methods
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$begin$ffa49c666f6d269c(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$end$95f4c539b22fc637(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *, jboolean);
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$implCloseChannel$230ed5fc012167e2(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);
extern jboolean _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$isOpen$ac3c28a31bf5ea5b(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$begin$ffa49c666f6d269c;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$end$95f4c539b22fc637;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$implCloseChannel$230ed5fc012167e2;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$isOpen$ac3c28a31bf5ea5b;

// Virtual methods structure
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods {
	void	(*begin$ffa49c666f6d269c)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);
	void	(*end$95f4c539b22fc637)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *, jboolean);
	void	(*implCloseChannel$230ed5fc012167e2)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);
	jboolean	(*isOpen$ac3c28a31bf5ea5b)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *);
};

// Vtable
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
};

// Vtype
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs {
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
};

// Object instance structure
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object {
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype	*vtype;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype _jc_java_nio_channels_spi_AbstractInterruptibleChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_spi_AbstractInterruptibleChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_spi_AbstractInterruptibleChannel$class_object;

#endif	/* _JC_java_nio_channels_spi_AbstractInterruptibleChannel_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/spi/AbstractInterruptibleChannel.h <==
// public abstract class java.nio.channels.spi.AbstractInterruptibleChannel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_spi_AbstractInterruptibleChannel_H_
#define _JC_java_nio_channels_spi_AbstractInterruptibleChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$object;

typedef const struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods;
typedef const struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable;
typedef const struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$begin$ffa49c666f6d269c(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$end$95f4c539b22fc637(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$implCloseChannel$230ed5fc012167e2(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method$isOpen$ac3c28a31bf5ea5b(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$begin$ffa49c666f6d269c;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$end$95f4c539b22fc637;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$implCloseChannel$230ed5fc012167e2;
extern _jc_method _jc_java_nio_channels_spi_AbstractInterruptibleChannel$method_info$isOpen$ac3c28a31bf5ea5b;

// Virtual methods structure
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods {
	void	(*begin$ffa49c666f6d269c)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;
	void	(*end$95f4c539b22fc637)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *, jboolean) _JC_JCNI_ATTR;
	void	(*implCloseChannel$230ed5fc012167e2)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;
	jboolean	(*isOpen$ac3c28a31bf5ea5b)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
};

// Vtype
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs {
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
};

// Object instance structure
struct _jc_java_nio_channels_spi_AbstractInterruptibleChannel$object {
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype	*vtype;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_spi_AbstractInterruptibleChannel$vtype _jc_java_nio_channels_spi_AbstractInterruptibleChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_spi_AbstractInterruptibleChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_spi_AbstractInterruptibleChannel$class_object;

#endif	/* _JC_java_nio_channels_spi_AbstractInterruptibleChannel_H_ */
